@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import aiohttp
+import asyncio
 
 from . import error
 
@@ -27,29 +28,30 @@ class ApiHost:
         self._loop = loop
 
     async def async_request(self, path, async_method, data=None):
+        # TODO: check timeout
+        client_timeout = self._timeout
 
         url = self.api_path(path)
 
         try:
-            # TODO: check timeout
-            client_timeout = self._timeout
             if data is not None:
                 response = await async_method(url, timeout=client_timeout, data=data)
             else:
                 response = await async_method(url, timeout=client_timeout)
 
             if response.status != 200:
-                raise error.HttpError(f"Http error: {response.status}")
+                raise error.HttpError(f"Request to {self.host}:{self.port} failed with HTTP {response.status}")
 
             return await response.json()
 
-        # TODO: just log errors instead?
-        except aiohttp.ServerTimeoutError:
-            raise error.TimeoutError("Timeout trying to connect")
+        except asyncio.TimeoutError as ex:
+            raise error.TimeoutError(f"Failed to connect to {self.host}:{self.port} within {client_timeout}s: ({ex})") from None
+
+        except aiohttp.ClientConnectionError as ex:
+            raise error.ConnectionError(f"Details: {ex}") from None
 
         except aiohttp.ClientError as ex:
-            self._logger.debug("ERR: %s", ex)
-            raise error.ClientError("Client Error: %s", ex)
+            raise error.ClientError(f"API request failed to {self.host}:{self.port} {ex}") from ex
 
     async def async_api_get(self, path):
         return await self.async_request(path, self._session.get)
